.. _bibliography:
.. index:: Bibliography

Bibliography
***************

.. [AngLinErh16]
   | M. Ångqvist, D. O. Lindroth, and P. Erhart
   | *Optimization of the Thermoelectric Power Factor:*
   | *Coupling between Chemical Order and Transport Properties*
   | Chemistry of Materials **28**, 6877 (2016)
   | `doi: 10.1021/acs.chemmater.6b02117 <http://dx.doi.org/10.1021/acs.chemmater.6b02117>`_

.. [AngMunRah19]
   | M. Ångqvist, W. A. Muñoz, J. M. Rahm, E. Fransson, C. Durniak, P. Rozyczko, T. H. Rod, and P. Erhart
   | *ICET – A Python Library for Constructing and Sampling Alloy Cluster Expansions*
   | Advanced Theory and Simulations **2**, 1900015 (2019)
   | `doi: 10.1002/adts.201900015 <https://doi.org/10.1002/adts.201900015>`_

.. [BluHarWal05]
   | V. Blum, G. L. W. Hart, M. J. Walorski, and A. Zunger
   | *Using genetic algorithms to map first-principles results to model Hamiltonians: Application to the generalized Ising model for alloys*
   | Physical Review B **72**, 165113 (2005)
   | `doi: 10.1103/PhysRevB.72.165113 <https://doi.org/10.1103/PhysRevB.72.165113>`_

.. [CanWak08]
   | E. J. Candès and M. B. Wakin
   | *An Introduction To Compressive Sampling*
   | Signal Processing Magazine, IEEE **25**, 201 (2008)
   | `doi: 10.1109/MSP.2007.914731 <http://dx.doi.org/10.1109/MSP.2007.914731>`_

.. [GolOsh09]
   | T. Goldstein and S. Osher
   | *The Split Bregman Method for L1-Regularized Problems*
   | SIAM Journal of Imaging Science **2**, 323 (2009)
   | `doi: 10.1137/080725891 <http://dx.doi.org/10.1137/080725891>`_

.. [HarFor08]
   | G. L. W. Hart and R. W. Forcade
   | *Algorithm for generating derivative structures*
   | Physical Review B **77**, 224115 (2008)
   | `doi: 10.1103/PhysRevB.77.224115 <http://dx.doi.org/10.1103/PhysRevB.77.224115>`_

.. [HarFor09]
   | G. L. W. Hart and R. W. Forcade
   | *Generating derivative structures from multilattices: Algorithm and application to hcp alloys*
   | Physical Review B **80**, 014120 (2009)
   | `doi: 10.1103/PhysRevB.80.014120 <http://dx.doi.org/10.1103/PhysRevB.80.014120>`_

.. [LakFerFro92]
   | D. B. Laks, L. G. Ferreira, S. Froyen, and A. Zunger
   | *Efficient cluster expansion for substitutional systems*
   | Phys. Rev. B **46**, 12587 (1992)
   | `doi: 10.1103/PhysRevB.46.12587 <https://doi.org/10.1103/PhysRevB.46.12587>`_

.. [LanTsaExl04]
   | D. P. Landau, S.-H. Tsai, and M. Exler
   | *A new approach to Monte Carlo simulations in statistical physics: Wang-Landau sampling*
   | American Journal of Physics **72**, 1294 (2004)
   | `doi: 10.1119/1.1707017 <https://doi.org/10.1119/1.1707017>`_

.. [MueCed09]
   | T. Mueller and G. Ceder
   | *Bayesian approach to cluster expansions*
   | Physical Review B **80**, 024103 (2009
   | `doi: 10.1103/PhysRevB.80.024103 <https://doi.org/10.1103/PhysRevB.80.024103>`_

.. [NelHarZho13]
   | L. J. Nelson, G. L. W. Hart, F. Zhou, and V. Ozoliņš
   | *Compressive sensing as a new paradigm for model building*
   | Physical Review B **87**, 035125 (2013)
   | `doi: 10.1103/PhysRevB.87.035125 <http://dx.doi.org/10.1103/PhysRevB.87.035125>`_

.. [NelOzoRee13]
   | L. J. Nelson, V. Ozoliņš, C. S. Reese, F. Zhou, and G. L. W. Hart
   | *Cluster expansion made easy with Bayesian compressive sensing*
   | Physical Review B **88**, 155105 (2013)
   | `doi: 10.1103/PhysRevB.88.155105 <http://dx.doi.org/10.1103/PhysRevB.88.155105>`_

.. [OzoWolZun98]
   | V. Ozoliņš, C. Wolverton, and Alex Zunger
   | *Effects of anharmonic strain on the phase stability of epitaxial films and superlattices: Applications to noble metals*
   | Phys. Rev. B **57**, 4816 (1998)
   | `doi: 10.1103/PhysRevB.57.4816 <http://dx.doi.org/10.1103/PhysRevB.57.4816>`_

.. [RahLofFra21]
   | J. M. Rahm, J. Löfgren, E. Fransson, and P. Erhart
   | *A tale of two phase diagrams: Interplay of ordering and hydrogen uptake in Pd–Au–H*
   | Acta Materialia **211**, 116893 (2021)
   | `doi: 10.1016/j.actamat.2021.116893 <https://doi.org/10.1016/j.actamat.2021.116893>`_

.. [SadErh12]
   | B. Sadigh, and P. Erhart
   | *Calculation of excess free energies of precipitates via direct thermodynamic integration across phase boundaries*
   | Physical Review B **86**, 134204 (2012)
   | `doi: 10.1103/PhysRevB.86.134204 <http://dx.doi.org/10.1103/PhysRevB.86.134204>`_

.. [SanDucGra84]
   | J. M. Sanchez, F. Ducastelle, and D. Gratias
   | *Generalized cluster description of multicomponent systems*
   | Physica A **42**, 334 (1984)
   | `doi: 10.1016/0378-4371(84)90096-7 <http://dx.doi.org/10.1016/0378-4371(84)90096-7>`_

.. [San10]
   | J. M. Sanchez
   | *Cluster expansion and the configurational theory of alloys*
   | Physical Review B **81**, 224202 (2010)
   | `doi: 10.1103/PhysRevB.81.224202 <http://dx.doi.org/10.1103/PhysRevB.81.224202>`_

.. [Wal09]
   | A. van de Walle
   | *Multicomponent multisublattice alloys, nonconfigurational entropy and other additions to the Alloy Theoretic Automated Toolkit*
   | Calphad **33**, 266 (2009)
   | `doi: 10.1016/j.calphad.2008.12.005 <http://dx.doi.org/10.1016/j.calphad.2008.12.005>`_

.. [WalTiwJon13]
   | A. van de Walle, P. Tiwary, M. de Jong, D.L. Olmsted, M. Asta, A. Dick, D. Shin, Y. Wang, L.-Q. Chen, and Z.-K. Liu
   | *Efficient stochastic generation of special quasirandom structures*
   | Calphad **42**, 13 (2013)
   | `doi: 10.1016/j.calphad.2013.06.006 <https://doi.org/10.1016/j.calphad.2013.06.006>`_

.. [WanLan01a]
   | F. Wang and D. P. Landau
   | *Efficient, Multiple-Range Random Walk Algorithm to Calculate the Density of States*
   | Physical Review Letters **86**, 2050 (2001)
   | `doi: 10.1103/PhysRevLett.86.2050 <https://doi.org/10.1103/PhysRevLett.86.2050>`_

.. [WanLan01b]
   | F. Wang and D. P. Landau
   | *Determining the density of states for classical statistical models: A random walk algorithm to produce a flat histogram*
   | Physical Review E **64**, 056101 (2001)
   | `doi: 10.1103/PhysRevE.64.056101 <https://doi.org/10.1103/PhysRevE.64.056101>`_

.. [ZunWeiFer90]
   | A. Zunger, S.-H. Wei, L. G. Ferreira, and J. E. Bernard.
   | *Special quasirandom structures*
   | Physical Review Letters **65**, 353 (1990)
   | `doi: 10.1103/PhysRevLett.65.353 <https://doi.org/10.1103/PhysRevLett.65.353>`_


Also see this :ref:`list of publications <publications>` using icet.
